@@ -87,6 +87,7 @@ Examples:
 		lineWidth := config.LineWidth
 		seq.AlphabetGuessSeqLengthThreshold = config.AlphabetGuessSeqLength
 		seq.ValidateSeq = false
+		usingDefaultIDRegexp := config.IDRegexp == fastx.DefaultIDRegexp
 		quiet := config.Quiet
 		runtime.GOMAXPROCS(config.Threads)
 
@@ -94,6 +95,7 @@ Examples:
 
 		files := getFileListFromArgsAndFile(cmd, args, true, "infile-list", true)
 
+		justCount := getFlagBool(cmd, "count")
 		pattern := getFlagStringSlice(cmd, "pattern")
 		patternFile := getFlagString(cmd, "pattern-file")
 		useRegexp := getFlagBool(cmd, "use-regexp")
@@ -195,8 +197,14 @@ Examples:
 						continue
 					}
 
-					if !quiet && strings.IndexAny(p, "\t ") >= 0 {
-						log.Warningf("space found in pattern: %s", p)
+					if !quiet {
+						if p[0] == '>' {
+							log.Warningf(`symbol ">" detected, it should not be a part of the sequence ID/name: %s`, p)
+						} else if p[0] == '@' {
+							log.Warningf(`symbol "@" detected, it should not be a part of the sequence ID/name. %s`, p)
+						} else if !byName && usingDefaultIDRegexp && strings.ContainsAny(p, "\t ") {
+							log.Warningf("space found in pattern, you may need use -n/--by-name: %s", p)
+						}
 					}
 
 					if degenerate || useRegexp {
@@ -247,9 +255,16 @@ Examples:
 			}
 		} else {
 			for _, p := range pattern {
-				if !quiet && strings.IndexAny(p, "\t ") >= 0 {
-					log.Warningf("space found in pattern: '%s'", p)
+				if !quiet {
+					if p[0] == '>' {
+						log.Warningf(`symbol ">" detected, it should not be a part of the sequence ID/name: %s`, p)
+					} else if p[0] == '@' {
+						log.Warningf(`symbol "@" detected, it should not be a part of the sequence ID/name. %s`, p)
+					} else if !byName && usingDefaultIDRegexp && strings.ContainsAny(p, "\t ") {
+						log.Warningf("space found in pattern, you may need use -n/--by-name: %s", p)
+					}
 				}
+
 				if degenerate || useRegexp {
 					if degenerate {
 						pattern2seq, err = seq.NewSeq(alphabet, []byte(p))
@@ -298,6 +313,8 @@ Examples:
 		var record *fastx.Record
 		strands := []byte{'+', '-'}
 
+		var count int
+
 		// -------------------------------------------------------------------
 		// only for searching with sequences and mismatch > 0, were FMI is very slow
 
@@ -321,6 +338,11 @@ Examples:
 
 				id = 1
 				for r := range ch {
+					if justCount {
+						count++
+						continue
+					}
+
 					_id = r.id
 
 					if _id == id { // right there
@@ -480,6 +502,9 @@ Examples:
 			close(ch)
 			<-done
 
+			if justCount {
+				fmt.Fprintf(outfh, "%d\n", count)
+			}
 			return
 		}
 
@@ -628,7 +653,11 @@ Examples:
 					}
 				}
 
-				record.FormatToWriter(outfh, config.LineWidth)
+				if justCount {
+					count++
+				} else {
+					record.FormatToWriter(outfh, config.LineWidth)
+				}
 
 				if immediateOutput {
 					outfh.Flush()
@@ -637,6 +666,10 @@ Examples:
 
 			config.LineWidth = lineWidth
 		}
+
+		if justCount {
+			fmt.Fprintf(outfh, "%d\n", count)
+		}
 	},
 }
 
@@ -658,6 +691,7 @@ func init() {
 		"e.g 1:12 for first 12 bases, -12:-1 for last 12 bases")
 	grepCmd.Flags().BoolP("circular", "c", false, "circular genome")
 	grepCmd.Flags().BoolP("immediate-output", "I", false, "print output immediately, do not use write buffer")
+	grepCmd.Flags().BoolP("count", "C", false, "just print a count of matching records. with the -v/--invert-match flag, count non-matching records")
 }
 
 var reUnquotedComma = regexp.MustCompile(`\{[^\}]*$|^[^\{]*\}`)
